@@ -23,12 +23,17 @@ parser.add_argument('--graph', action="store_true", help="Print Mermaid diagram
 parser.add_argument(
     '--env', default="", help="Sets TEST_ENV_NAME env variable used by env/loader.py"
 )
+parser.add_argument(
+    '--skip-teardown', action="store_true", help="Do not run test cases that have `run_last=True`"
+)
 
 
 def main():
     args = parser.parse_args()
     if args.env:
         os.environ["TEST_ENV_NAME"] = args.env
+    if args.skip_teardown:
+        os.environ["ENTEST_SKIP_TEARDOWN"] = "yes"
     paths = [Path(path) for path in args.paths]
     test_discovery(paths, info)
     if args.graph:
